@@ -21,19 +21,15 @@
 import os
 import tempfile
 
-from .libtoolimporter import LibtoolImporter
 from .message import Position
 from .ccompiler import CCompiler
 from .utils import have_debug_flag, dll_dirs
 
-with LibtoolImporter(None, None):
-    dlldirs = dll_dirs()
-    dlldirs.add_dll_dirs(['gio-2.0'])
-    if 'UNINSTALLED_INTROSPECTION_SRCDIR' in os.environ:
-        from _giscanner import SourceScanner as CSourceScanner
-    else:
-        from giscanner._giscanner import SourceScanner as CSourceScanner
-    dlldirs.cleanup_dll_dirs()
+
+dlldirs = dll_dirs()
+dlldirs.add_dll_dirs(['gio-2.0'])
+from giscanner._giscanner import SourceScanner as CSourceScanner
+dlldirs.cleanup_dll_dirs()
 
 HEADER_EXTS = ['.h', '.hpp', '.hxx']
 SOURCE_EXTS = ['.c', '.cpp', '.cc', '.cxx']
@@ -118,7 +114,7 @@ def ctype_name(ctype):
 
 class SourceType(object):
     __members__ = ['type', 'base_type', 'name', 'type_qualifier',
-                   'child_list', 'is_bitfield']
+                   'child_list', 'is_bitfield', 'function_specifier']
 
     def __init__(self, scanner, stype):
         self._scanner = scanner
@@ -158,6 +154,10 @@ class SourceType(object):
     def is_bitfield(self):
         return self._stype.is_bitfield
 
+    @property
+    def function_specifier(self):
+        return self._stype.function_specifier
+
 
 class SourceSymbol(object):
     __members__ = ['const_int', 'const_double', 'const_string', 'const_boolean',
@@ -232,6 +232,7 @@ class SourceScanner(object):
         self._scanner = CSourceScanner()
         self._filenames = []
         self._cpp_options = []
+        self._compiler = None
 
     # Public API
 
@@ -245,6 +246,9 @@ class SourceScanner(object):
                 if opt not in self._cpp_options:
                     self._cpp_options.append(opt)
 
+    def set_compiler(self, compiler):
+        self._compiler = compiler
+
     def parse_files(self, filenames):
         for filename in filenames:
             # self._scanner expects file names to be canonicalized and symlinks to be resolved
@@ -291,7 +295,7 @@ class SourceScanner(object):
         defines = ['__GI_SCANNER__']
         undefs = []
 
-        cc = CCompiler()
+        cc = CCompiler(compiler_name=self._compiler)
 
         tmp_fd_cpp, tmp_name_cpp = tempfile.mkstemp(prefix='g-ir-cpp-',
                                                     suffix='.c',
